@@ -49,6 +49,13 @@ cdgd1_ml <- function(Y,D,G,X,Q,data,algorithm,alpha=0.05,trim1=0,trim2=0) {
 
   data <- as.data.frame(data)
 
+  if ( sum(is.na(data[,c(Y,D,G,X,Q)]))>0 ) {
+    stop(
+      "There are missing values in key variables.",
+      call. = FALSE
+    )
+  }
+
   ### estimate the nuisance functions with cross-fitting
   sample1 <- sample(nrow(data), floor(nrow(data)/2), replace=FALSE)
   sample2 <- setdiff(1:nrow(data), sample1)
